@@ -64,6 +64,7 @@ import pandas as pd
 import sys
 import warnings
 import platform
+import errno, stat
 
 # Libraries for second version
 from DSSATTools import __file__ as DSSATModulePath
@@ -75,7 +76,7 @@ from DSSATTools.management import Management
 from DSSATTools.base.sections import TabularSubsection, RowBasedSection
 from DSSATTools.base.sections import clean_comments
 
-
+OS = platform.system().lower()
 OUTPUTS = ['PlantGro', ]
 
 CUL_VARNAME = {
@@ -90,10 +91,24 @@ CUL_VARNAME = {
     'SB': 'VAR-NAME........',
     'CN': 'VRNAME..........',
     'SU': 'VAR-NAME........',
-    'PT': 'VAR-NAME........'
+    'PT': 'VAR-NAME........',
+    'TM': 'VRNAME..........',
+    'CB': 'VRNAME..........'
 }
 PERENIAL_FORAGES = ['Alfalfa', 'Bermudagrass', 'Brachiaria', 'Bahiagrass']
+ROOTS = ['Potato']
 
+# function to handle windows permisions
+def handleRemoveReadonly(func, path, excinfo):
+    os.chmod(path, stat.S_IWRITE)
+    func(path)
+
+if 'windows' in OS:
+    WIN_SHUTIL_KWARGS = {'ignore_errors': False, 'onerror': handleRemoveReadonly}
+    CHMOD_MODE = stat.S_IWRITE
+else:
+    WIN_SHUTIL_KWARGS = {}
+    CHMOD_MODE = 111
 class DSSAT():
     '''
     Class that represents the simulation environment. When initializing and seting up the environment, a new folder is created (usually in the tmp folder), and all of the necesary files to run the model are copied into it.
@@ -101,7 +116,7 @@ class DSSAT():
     def __init__(self):
         BASE_PATH = os.path.dirname(DSSATModulePath)
         self._STATIC_PATH = os.path.join(BASE_PATH, 'static')
-        if 'windows'in platform.system().lower():
+        if 'windows'in OS:
             self._BIN_PATH = os.path.join(self._STATIC_PATH, 'bin', 'dscsm048.exe')
             self._CONFILE = 'DSSATPRO.V48'
         else: 
@@ -151,7 +166,7 @@ class DSSAT():
             )
             os.chmod(
                 os.path.join(self._RUN_PATH, os.path.basename(self._BIN_PATH)),
-                mode=111
+                mode=CHMOD_MODE
             )
         for file in os.listdir(self._STATIC_PATH):
             if file.endswith('.CDE'):
@@ -165,7 +180,7 @@ class DSSAT():
         shutil.copytree(self._STATIC_PATH, os.path.join(self._RUN_PATH, 'static'))
         sys.stdout.write(f'Static files copied to {self._RUN_PATH}.\n')
         self._STATIC_PATH = os.path.join(self._RUN_PATH, 'static')
-        if 'windows'in platform.system().lower():
+        if 'windows'in OS:
             self._BIN_PATH = os.path.join(self._STATIC_PATH, 'bin', 'dscsm048.exe')
         else: 
             self._BIN_PATH = os.path.join(self._STATIC_PATH, 'bin', 'dscsm048')
@@ -200,17 +215,19 @@ class DSSAT():
         assert self._SETUP, 'You must initialize the simulation environment by'\
             + ' running the setup() method'
 
-        # Remove previous outputs
+        # Remove previous outputs and inputs
         OUTPUT_FILES = [i for i in os.listdir(self._RUN_PATH) if i[-3:] == 'OUT']
-        for file in OUTPUT_FILES:
+        INP_FILES = [i for i in os.listdir(self._RUN_PATH) if i[-3:] in ['INP', 'INH']]
+        for file in (OUTPUT_FILES + INP_FILES):
             os.remove(os.path.join(self._RUN_PATH, file))
+        
         # Fill Managament fields
         management.cultivars['CR'] = crop.CODE
         management.cultivars['CNAME'] = \
             crop.cultivar[management.cultivar][CUL_VARNAME[crop.CODE]]
 
         management.fields['WSTA....'] = weather.INSI \
-            + management.sim_start.strftime('%y%m')
+            + management.sim_start.strftime('%y01')
         management.fields['SLDP'] = soil.total_depth
         management.fields['ID_SOIL'] = soil.id
 
@@ -231,16 +248,16 @@ class DSSAT():
         table = table.sort_values(by='ICBL').reset_index(drop=True)
         table['SNH4'] = [0.]*len(table)
         table['SNO3'] = [1.] + [0.]*(len(table)-1)
-        if crop.NAME.lower() == 'potato':
+        if crop.NAME in ROOTS:
             assert not any(pd.isna(management.planting_details['table'][['PLWT', 'SPRL']]).values[0]), \
-                "PLWT, SPRL transplanting parameters are mandatory for Potato crop, you must "\
+                f"PLWT, SPRL transplanting parameters are mandatory for {crop.NAME} crop, you must "\
                 "define those parameters in management.planting_details['table']"
         management.initial_conditions['table'] = table
 
         management.simulation_controls['SMODEL'] = crop.SMODEL        
 
         management_filename = weather.INSI \
-            + management.sim_start.strftime('%y%m') \
+            + management.sim_start.strftime('%y01') \
             + f'.{crop.CODE}X'
         management_filename = os.path.join(self._RUN_PATH, management_filename) 
         management.write(filename=management_filename)
@@ -315,7 +332,7 @@ class DSSAT():
         '''
         Removes the simulation environment (tmp folder and files).
         '''
-        shutil.rmtree(self._RUN_PATH)
+        shutil.rmtree(self._RUN_PATH, **WIN_SHUTIL_KWARGS)
         sys.stdout.write(f'{self._RUN_PATH} and its content has been removed.\n')
     
 
